def compare_versions(version1: str, version2: str) -> int:
    """Compare 2 version strings

    :param version1: Version string; dot separated numbers; white spaces in between are not considered
    :param version2: Version string; dot separated numbers; white spaces in between are not considered
    :return:
        positive number: If the first version is greater than the second
        negative number: If the first version is smaller than the second
        zero: If the versions are equals
    """

    version1, version2 = (map(int, v.split('.')) for v in [version1, version2])
    version1, version2 = zip(*map(lambda p1, p2: (p1 or 0, p2 or 0), version1, version2))

    for i in range(len(version1)):
        if version1[i] != version2[i]:
            return version1[i] - version2[i]
    return 0



from setuptools import setup

setup(
    name='cf_compare_versions',
    version='0.0.1',
    packages=['compare_versions'],
    url='https://github.com/carlos-ferras/code-challenge/compare_versions',
    license='MIT',
    author='Carlos Ferras',
    author_email='c4rlos.ferra5@gmail.com',
    description='Compare version strings',
    long_description=open("README.md", "r").read(),
    long_description_content_type="text/markdown"
)
